# File: input_file.bin

Field | Value
--- | ---
Parser | FooParser
File Path | C:/input_file.bin
Description | SuperMalware Implant
Architecture |
MD5 | 1e50210a0202497fb79bc38b6ade6c34
SHA1 | baf34551fecb48acc3da868eb85e1b6dac9de356
SHA256 | 1307990e6ba5ca145eb35e99182a9bec46531bc54ddf656a602c780fa0240dee
Compile Time |

## RSA Private Key

Value
    Modulus (n):
        9a:10:6f:8d:3e:4b:bb:73:1e:b2:aa:0e:c7:e9:a0:
        d3:1b:fb:db:5a:ce:26:92:d2:3d:db:2a:95:ae:78:
        ad:7a:e0:2d:90:73:38:5b:57:72:5a:28:10:f3:1f:
        84:ff:3b:31:f8:4f:f3:b3:1f:84:ff:3b:31:f8:4f:
        f3:b3
    Public Exponent (e):
        1234 (0x4d2)
    Private Exponent (d):
        1234 (0x4d2)
    p:
        9a:10:6f:8d:3e:4b:bb:73:1e:b2:aa:0e:c7:e9:a0:
        d3:1b:fb:db:5a:ce:26:92:d2:3d:db:2a:95:ae:78:
        ad:7a:e0:2d:90:73:38:5b:57:72:5a:28:10:f3:1f:
        84:ff:3b:31:f8:4f:f3:b3:1f:84:ff:3b:31:f8:4f:
        f3:b3
    q:
        9a:10:6f:8d:3e:4b:bb:73:1e:b2:aa:0e:c7:e9:a0:
        d3:1b:fb:db:5a:ce:26:92:d2:3d:db:2a:95:ae:78:
        ad:7a:e0:2d:90:73:38:5b:57:72:5a:28:10:f3:1f:
        84:ff:3b:31:f8:4f:f3:b3:1f:84:ff:3b:31:f8:4f:
        f3:b3
    d mod (p-1):
        9a:10:6f:8d:3e:4b:bb:73:1e:b2:aa:0e:c7:e9:a0:
        d3:1b:fb:db:5a:ce:26:92:d2:3d:db:2a:95:ae:78:
        ad:7a:e0:2d:90:73:38:5b:57:72:5a:28:10:f3:1f:
        84:ff:3b:31:f8:4f:f3:b3:1f:84:ff:3b:31:f8:4f:
        f3:b3
    d mod (q-1):
        9a:10:6f:8d:3e:4b:bb:73:1e:b2:aa:0e:c7:e9:a0:
        d3:1b:fb:db:5a:ce:26:92:d2:3d:db:2a:95:ae:78:
        ad:7a:e0:2d:90:73:38:5b:57:72:5a:28:10:f3:1f:
        84:ff:3b:31:f8:4f:f3:b3:1f:84:ff:3b:31:f8:4f:
        f3:b3
    (inverse of q) mod p:
        9a:10:6f:8d:3e:4b:bb:73:1e:b2:aa:0e:c7:e9:a0:
        d3:1b:fb:db:5a:ce:26:92:d2:3d:db:2a:95:ae:78:
        ad:7a:e0:2d:90:73:38:5b:57:72:5a:28:10:f3:1f:
        84:ff:3b:31:f8:4f:f3:b3:1f:84:ff:3b:31:f8:4f:
        f3:b3

## RSA Public Key

Value
    Modulus (n):
        9a:10:6f:8d:3e:4b:bb:73:1e:b2:aa:0e:c7:e9:a0:
        d3:1b:fb:db:5a:ce:26:92:d2:3d:db:2a:95:ae:78:
        ad:7a:e0:2d:90:73:38:5b:57:72:5a:28:10:f3:1f:
        84:ff:3b:31:f8:4f:f3:b3:1f:84:ff:3b:31:f8:4f:
        f3:b3
    Public Exponent (e):
        1234 (0x4d2)

## User Agent

Value
    This is a really large user agent that will need to be word wrapped.This is a really large user
    agent that will need to be word wrapped.This is a really large user agent that will need to be word
    wrapped.This is a really large user agent that will need to be word wrapped.This is a really large
    user agent that will need to be word wrapped.This is a really large user agent that will need to be
    word wrapped.This is a really large user agent that will need to be word wrapped.This is a really
    large user agent that will need to be word wrapped.This is a really large user agent that will need
    to be word wrapped.This is a really large user agent that will need to be word wrapped.This is a
    really large user agent that will need to be word wrapped.This is a really large user agent that
    will need to be word wrapped.This is a really large user agent that will need to be word
    wrapped.This is a really large user agent that will need to be word wrapped.This is a really large
    user agent that will need to be word wrapped.This is a really large user agent that will need to be
    word wrapped.

# File Tree

    <input_file.bin (1e50210a0202497fb79bc38b6ade6c34) : SuperMalware Implant>